@@ -15,10 +15,7 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/pipeline",
-    "0.3.14",
-    __name__[0:-6],
-    "pipeline@0.3.14.jsii.tgz",
+    "@aws-prototyping-sdk/pipeline", "0.4.0", __name__[0:-6], "pipeline@0.4.0.jsii.tgz"
 )
 
 __all__ = [
